==> lsr-0.2.1.tar.bz2: lsr-0.2.1/src/Adapters/ATSPI/__init__.py <==
'''
Defines L{AccAdapt.Adapter}s for objects accessible objects in the AT-SPI
toolkit.

@author: Peter Parente
@author: Pete Brunet
@author: Brett Clippingdale
@organization: IBM Corporation
@copyright: Copyright (c) 2005, 2006 IBM Corporation
@license: Common Public License 1.0

All rights reserved. This program and the accompanying materials are made
available under the terms of the Common Public License v1.0 which accompanies
this distribution, and is available at
U{http://www.opensource.org/licenses/cpl1.0.php}
'''
from DefaultInfo import *
from DefaultAction import *
from DefaultNav import *
from DefaultEventHandler import *

from FactoryAdapter import *

from ContainerAdapter import *
from TextAdapter import *
from TableAdapter import *
from TreeAdapter import *
from ComboboxAdapter import *
from PopupAdapter import *
from ImageAdapter import *

# register all Adapter subclasses in order from most specific to least
import AccAdapt
AccAdapt.registerAdapters([ComboboxEventHandlerAdapter,
                           PopupMenuEventHandlerAdapter,
                           TextEventHandlerAdapter,
                           SimpleTextEventHandlerAdapter,
                           TableEventHandlerAdapter,
                           DegenerateTableEventHandlerAdapter,
                           DefaultEventHandlerAdapter])
AccAdapt.registerAdapters([ImageAccInfoAdapter,
                           MenuPopupAccInfoAdapter,
                           TextAccInfoAdapter,
                           TreeAccInfoAdapter,
                           TableAccInfoAdapter,
                           ContainerAccInfoAdapter,
                           DefaultAccInfoAdapter])
AccAdapt.registerAdapters([ContainerAccActionAdapter,
                           DefaultAccActionAdapter])
AccAdapt.registerAdapters([TreeNavAdapter, 
                           TableNavAdapter, 
                           TextNavAdapter,
                           DefaultNavAdapter])
AccAdapt.registerAdapters([PORFromPORAdapter,PORFromAccessibleAdapter])

==> lsr-0.3.1.tar.bz2: lsr-0.3.1/src/Adapters/ATSPI/__init__.py <==
'''
Defines L{AccAdapt.Adapter}s for objects accessible objects in the AT-SPI
toolkit.

@author: Peter Parente
@author: Pete Brunet
@author: Brett Clippingdale
@organization: IBM Corporation
@copyright: Copyright (c) 2005, 2006 IBM Corporation
@license: Common Public License 1.0

All rights reserved. This program and the accompanying materials are made
available under the terms of the Common Public License v1.0 which accompanies
this distribution, and is available at
U{http://www.opensource.org/licenses/cpl1.0.php}
'''
from DefaultInfo import *
from DefaultAction import *
from DefaultNav import *
from DefaultEventHandler import *

from FactoryAdapter import *

from ContainerAdapter import *
from TextAdapter import *
from TableAdapter import *
from TreeAdapter import *
from ComboboxAdapter import *
from PopupAdapter import *
from ImageAdapter import *
from HypertextAdapter import *

# register all Adapter subclasses in order from most specific to least
import AccAdapt
AccAdapt.registerAdapters([HypertextEventHandlerAdapter,
                           ComboboxEventHandlerAdapter,
                           PopupMenuEventHandlerAdapter,
                           TextEventHandlerAdapter,
                           SimpleTextEventHandlerAdapter,
                           TableEventHandlerAdapter,
                           DegenerateTableEventHandlerAdapter,
                           DefaultEventHandlerAdapter])
AccAdapt.registerAdapters([HypertextAccInfoAdapter,
                           ImageAccInfoAdapter,
                           MenuPopupAccInfoAdapter,
                           TextAccInfoAdapter,
                           TreeAccInfoAdapter,
                           TableAccInfoAdapter,
                           ContainerAccInfoAdapter,
                           DefaultAccInfoAdapter])
AccAdapt.registerAdapters([ContainerAccActionAdapter,
                           DefaultAccActionAdapter])
AccAdapt.registerAdapters([HypertextNavAdapter,
                           TreeNavAdapter, 
                           TableNavAdapter, 
                           TextNavAdapter,
                           DefaultNavAdapter])
AccAdapt.registerAdapters([PORFromPORAdapter, PORFromAccessibleAdapter])
